@@ -5,10 +5,11 @@
 //  Created by Joe Song on 11/2/11.
 //  Copyright (c) 2011 New Mexico State University. All rights reserved.
 //
-//  Hua modified, replace all distribution computation into boost functions. //Hua modified Feb 6, 2015
 
-//#include <iostream>
+#include <iostream>
+#include <cassert>
 
+//Hua modified, replace all distribution computation into boost functions. //Hua modified Feb 6, 2015
 #include "boost/math/distributions/fisher_f.hpp"
 #include "boost/math/distributions/gamma.hpp"
 #include "boost/math/distributions/normal.hpp"
@@ -31,6 +32,7 @@ double ChisqPvalue(double x, int df)
     // modified by Yang Zhang 11.2.2010 x may be a slightly smaller than zero due to numerical issues
     
     //Hua modified Feb 6, 2015
+    assert(df >= 0);
     if(x <= 0)
         return 1;
     else
